@@ -422,13 +422,19 @@ rase = function(tree, polygons, niter=1e3, logevery=10, sigma2_scale=0.05, scree
   if (!is(tree, "phylo")) {
     stop('tree should be of class phylo')
   }
+
+  if (!any(sapply(polygons, is.owin))) {
+    stop('one or more polygons are not in \'owin\' format')
+  }
   
+  if (any(sapply(polygons, is.empty))) {
+    stop('one or more polygons are empty')
+  }  
+
   if (any(is.na(match(tree$tip.label, names(polygons))))) {
     stop('tip labels and polygon names do not match')
   }
   
-  ####Calculate all areas before hand!
-  
   ntaxa = length(tree$tip.label)
   nnode = tree$Nnode
   
